@@ -49,7 +49,7 @@ struct _GnomeDbComboClass {
 
 GType      gnome_db_combo_get_type (void);
 GtkWidget *gnome_db_combo_new (void);
-GtkWidget *gnome_db_combo_new_with_model (GdaDataModel *model, gint pos);
+GtkWidget *gnome_db_combo_new_with_model (GdaDataModel *model, gint col);
 void       gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint col);
 GdaDataModel *gnome_db_combo_get_model (GnomeDbCombo *combo);
 gint       gnome_db_combo_get_column (GnomeDbCombo *combo);
