@@ -76,8 +76,8 @@ data_model_info_get_type (void)
 static void
 column_clicked_cb (GtkTreeViewColumn *column, gpointer user_data)
 {
-	//gtk_tree_view_set_search_column (GTK_TREE_VIEW (user_data),
-	//				 gtk_tree_view_column_get_sort_column_id (column));
+	gtk_tree_view_set_search_column (GTK_TREE_VIEW (user_data),
+					 gtk_tree_view_column_get_sort_column_id (column));
 }
 
 static gint
@@ -85,7 +85,6 @@ sort_values (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpoint
 {
 	DataModelInfo *infoa, *infob;
 	const GdaValue *valuea, *valueb;
-	gint retval = 1;
 
 	gtk_tree_model_get (model, itera, 0, &infoa, -1);
 	gtk_tree_model_get (model, iterb, 0, &infob, -1);
@@ -98,39 +97,8 @@ sort_values (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpoint
 	valueb = gda_data_model_get_value_at (infob->model,
 					      GPOINTER_TO_INT (user_data),
 					      infob->row);
-	if (!valuea || !valueb)
-		return 0;
-
-	/* compare values */
-	if (gda_value_isa ((GdaValue *) valuea, GDA_VALUE_TYPE_NULL) &&
-	    gda_value_isa ((GdaValue *) valueb, GDA_VALUE_TYPE_NULL))
-		retval = 0;
-	else if (gda_value_isa ((GdaValue *) valuea, GDA_VALUE_TYPE_BIGINT) &&
-		 gda_value_isa ((GdaValue *) valueb, GDA_VALUE_TYPE_BIGINT)) {
-		if (gda_value_get_bigint ((GdaValue *) valuea) >
-		    gda_value_get_bigint ((GdaValue *) valueb))
-			retval = -1;
-	}
-	else {
-		gchar *stra, *strb;
-
-		/* data types don't match, so use strings to sort */
-		stra = gda_value_stringify ((GdaValue *) valuea);
-		strb = gda_value_stringify ((GdaValue *) valueb);
-		if (!stra && !strb)
-			retval = 0;
-		else if (!stra)
-			retval = 1;
-		else if (!strb)
-			retval = -1;
-		else
-			retval = strcmp (stra, strb);
-
-		g_free (stra);
-		g_free (strb);
-	}
-
-	return retval;
+	
+	return gda_value_compare (valuea, valueb);
 }
 
 /*
@@ -147,7 +115,6 @@ default_value_set_func (GtkTreeViewColumn *tree_column,
 	DataModelInfo *info = NULL;
 	GdaValue *value;
 	gchar *txt;
-	gchar *str;
 
 	gtk_tree_model_get (model, iter, 0, &info, -1);
 	if (!info)
@@ -168,13 +135,11 @@ default_value_set_func (GtkTreeViewColumn *tree_column,
 	    || gda_value_isa (value, GDA_VALUE_TYPE_SMALLINT)
 	    || gda_value_isa (value, GDA_VALUE_TYPE_TINYINT)) {
 		/* FIXME: get color for numbers from configuration */
-		str = g_strdup_printf ("<span foreground=\"#0000FF\">%s</span>", txt);
-		g_object_set (G_OBJECT (cell), "markup", str,
+		g_object_set (G_OBJECT (cell), "text", txt,
+			      "foreground", "blue",
 			      "xalign", 1.0,
 			      "yalign", 0.0, NULL);
-		g_free (str);
-	}
-	else
+	} else
 		g_object_set (G_OBJECT (cell), "text", txt, "yalign", 0.0, NULL);
 
 	g_free (txt);
@@ -347,10 +312,10 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 
 	col_count = gda_data_model_get_n_columns (model);
 	if (col_count > 0) {
-		//gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (tree_view),
-		//				     (GtkTreeViewSearchEqualFunc) tree_view_equal_func,
-		//				     tree_view, NULL);
-		//gtk_tree_view_set_search_column (GTK_TREE_VIEW (tree_view), 0);
+		gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (tree_view),
+						     (GtkTreeViewSearchEqualFunc) tree_view_equal_func,
+						     tree_view, NULL);
+		gtk_tree_view_set_search_column (GTK_TREE_VIEW (tree_view), 0);
 	}
 
 	for (i = 0; i < col_count; i++) {
@@ -368,7 +333,7 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 		}
 		attrs = gda_data_model_describe_column (model, i);
 		if (attrs && attrs->gda_type == GDA_VALUE_TYPE_BOOLEAN) {
-						renderer = gtk_cell_renderer_toggle_new ();
+			renderer = gtk_cell_renderer_toggle_new ();
 			gtk_tree_view_insert_column_with_data_func (
 				GTK_TREE_VIEW (tree_view),
 				i,
@@ -377,8 +342,7 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 				toggle_value_set_func,
 				GINT_TO_POINTER (i),
 				NULL);
-		}
-		else {
+		} else {
 			renderer = gtk_cell_renderer_text_new ();
 			gtk_tree_view_insert_column_with_data_func (
 				GTK_TREE_VIEW (tree_view),
